==> link_description_attributes-1.0.0.tar.gz: link_description_attributes/src/Plugin/Field/FieldWidget/LinkDescriptionWithAttributesWidget.php <==
<?php

namespace Drupal\link_description_attributes\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\link_attributes\LinkAttributesManager;
use Drupal\link_attributes\Plugin\Field\FieldWidget\LinkWithAttributesWidget;
use Drupal\link_description_attributes\LinkDescriptionWithAttributesWidgetTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'link' widget.
 *
 * @FieldWidget(
 *   id = "link_attributes",
 *   label = @Translation("Link description (with attributes)"),
 *   field_types = {
 *     "link_description"
 *   }
 * )
 */
class LinkDescriptionWithAttributesWidget extends LinkWithAttributesWidget {

  use LinkDescriptionWithAttributesWidgetTrait;

  /**
   * {@inheritdoc}
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, LinkAttributesManager $link_attributes_manager) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings, $link_attributes_manager);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('plugin.manager.link_attributes')
    );
  }

}

==> link_description_attributes-1.0.1.tar.gz: link_description_attributes/src/Plugin/Field/FieldWidget/LinkDescriptionWithAttributesWidget.php <==
<?php

namespace Drupal\link_description_attributes\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\link_attributes\LinkAttributesManager;
use Drupal\link_attributes\Plugin\Field\FieldWidget\LinkWithAttributesWidget;
use Drupal\link_description_attributes\LinkDescriptionWithAttributesWidgetTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'link_description_attributes' widget.
 *
 * @FieldWidget(
 *   id = "link_description_attributes",
 *   label = @Translation("Link description (with attributes)"),
 *   field_types = {
 *     "link_description"
 *   }
 * )
 */
class LinkDescriptionWithAttributesWidget extends LinkWithAttributesWidget {

  use LinkDescriptionWithAttributesWidgetTrait;

  /**
   * {@inheritdoc}
   */
  public function __construct($plugin_id, $plugin_definition, FieldDefinitionInterface $field_definition, array $settings, array $third_party_settings, LinkAttributesManager $link_attributes_manager) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings, $link_attributes_manager);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('plugin.manager.link_attributes')
    );
  }

}
